﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using FoursquareNET.Schema;

namespace FoursquareNET.Tip
{
    public class Add
    {
        private const string URL = "http://api.foursquare.com/v1/addtip";
        private const Common.HttpRequestMethod HTTP_REQUEST_METHOD = Common.HttpRequestMethod.POST;
        
        private List<Parameter> Parameters = new List<Parameter>();

        /// <summary>
        /// Allows you to add a new tip or to-do at a venue.
        /// </summary>
        /// <param name="returnFormat"></param>
        public Add()
        {
            
        }

        public Schema.Tip Execute(Credential credential)
        {
            Parameters.Clear();
            Parameters.Add(_VenueId);
            Parameters.Add(_Text);
            Parameters.Add(_Type);
            Parameters.Add(_Geolat);
            Parameters.Add(_Geolong);

            string result = Common.HTTPPost(URL, Parameters, credential, HTTP_REQUEST_METHOD);

            return new System.Web.Script.Serialization.JavaScriptSerializer().Deserialize<Schema.TipObj>(result).Tip;
        }

        #region Parameters

        private Parameter _VenueId = new Parameter("VenueId", "vid", true);
        private Parameter _Text = new Parameter("Text", "text", true);
        private Parameter _Type = new Parameter("Type", "type", false);
        private Parameter _Geolat = new Parameter("Geolat", "geolat", false);
        private Parameter _Geolong = new Parameter("Geolong", "geolong", true);

        /// <summary>
        /// the venue where you want to add this tip (required)
        /// </summary>
        public int VenueId { set { _VenueId.Value = value.ToString(); } }

        /// <summary>
        /// the text of the tip or to-do item (required)
        /// </summary>
        public string Text { set { _Text.Value = value; } }

        /// <summary>
        /// specify one of 'tip' or 'todo' (optional, default: tip)
        /// </summary>
        public TipType? TipType { set { _Type.Value = value != null ? value.ToString() : string.Empty; } }

        /// <summary>
        /// (optional, but recommended)
        /// </summary>
        public string Geolat { set { _Geolat.Value = value; } }

        /// <summary>
        /// (optional, but recommended)
        /// </summary>
        public string Geolong { set { _Geolong.Value = value; } }

        #endregion
    }
}
