﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace FoursquareNET.Venue
{
    public class NearbyAndSearch
    {
        private const string URL = "http://api.foursquare.com/v1/venues";
        private const Common.HttpRequestMethod HTTP_REQUEST_METHOD = Common.HttpRequestMethod.GET;
        private List<Parameter> Parameters = new List<Parameter>();

        /// <summary>
        /// Returns a list of venues near the area specified or that match the search term. (The distance returned is in meters). 
        /// If you authenticate, the method will return venue meta-data related to you and your friends. 
        /// If you do not authenticate, you will not get this data.
        /// </summary>
        /// <param name="returnFormat"></param>
        public NearbyAndSearch()
        {
        }

        public List<Schema.VenueGroup> Execute()
        {
            return Execute(new Credential());
        }

        public List<Schema.VenueGroup> Execute(Credential credential)
        {
            Parameters.Clear();
            Parameters.Add(_Geolat);
            Parameters.Add(_Geolong);
            Parameters.Add(_Limit);
            Parameters.Add(_SearchTerm);

            string result = Common.HTTPPost(URL, Parameters, credential, HTTP_REQUEST_METHOD);

            return new System.Web.Script.Serialization.JavaScriptSerializer().Deserialize<Schema.VenuesObj>(result).Groups;
        }

        #region Parameters

        private Parameter _Geolat = new Parameter("Geolat", "geolat", true);
        private Parameter _Geolong = new Parameter("Geolong", "geolong", true);
        private Parameter _Limit = new Parameter("Limit", "l", false);
        private Parameter _SearchTerm = new Parameter("SearchTerm", "q", false);
        

        /// <summary>
        /// latitude (required)
        /// </summary>
        public string Geolat { set { _Geolat.Value = value; } }

        /// <summary>
        /// longitude (required)
        /// </summary>
        public string Geolong { set { _Geolong.Value = value; } }

        /// <summary>
        /// limit of results (optional, default 10, maximum 50)
        /// </summary>
        public int? Limit { set { _Limit.Value = value != null ? value.ToString() : string.Empty; ; } }

        /// <summary>
        /// keyword search (optional)
        /// </summary>
        public string SearchTerm { set { _SearchTerm.Value = value; } }

        #endregion
    }
}
